@@ -1,6 +1,7 @@
 import requests
 
-import ext
+from .ext import exec_ext
+# import ext
 
 urls = [
     "https://google.com",
@@ -17,8 +18,7 @@ urls = [
 
 
 def main():
-  print("version '1.5.2'")
-  ext.exec_ext()
+  exec_ext()
 
   for url in urls:
     try:
@@ -28,9 +28,9 @@ def main():
       print(f"{url} - DOWN")
 
 
-# def intro_app():
-#   print("Hello, World!")
-#   exec()
+def intro_app():
+  print("Hello, World!")
+  exec()
 
 
 # ================
